__version__ = '0.0.15'
__author__ = 'Loris Henrion'
__author_email__ = 'loris_henrion@bce.lu'
__description__ = 'Syncing permissions on IP Addresses with those from their corresponding Prefix in NetBox'
__license__ = 'GPL-3.0'
